pyprocar.io.vasp.Kpoints — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# pyprocar.io.vasp.Kpoints

class pyprocar.io.vasp.Kpoints(filename='KPOINTS', has_time_reversal=True)

  A class to parse the KPOINTS file

  Parameters:

    - filename (str, optional) – The KPOINTS filename, by default “KPOINTS”

    - has_time_reversal (bool, optional) – A boolean vlaue to determine if the kpioints has time reversal symmetry, by default True

  Methods

  `Kpoints.__init__`([filename, has_time_reversal]) |